#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_VALMIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_VALMIN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/valmin.hpp>

#endif
